import bt
import pandas as pd
import numpy as np
from xtquant import xtdata
import matplotlib.pyplot as plt

# 数据的列名
columns = ['open', 'high', 'low', 'close', 'volume', 'amount', 'settelmentPrice',
           'openInterest', 'preClose', 'suspendFlag']


def get_local_data(field_list: list, stock_list: list, period: str, start_time: str, end_time: str,
                   count: int, dividend_type: str, fill_data: bool, data_dir: str):
    result = xtdata.get_local_data(field_list=field_list, stock_list=stock_list, period=period, start_time=start_time,
                                   end_time=end_time, count=count, dividend_type=dividend_type, fill_data=fill_data,
                                   data_dir=data_dir)
    return data_processing(result)


# 数据处理函数
def data_processing(result_local):
    # 初始化一个空的列表，用于存储每个股票的数据框
    df_list = []

    # 遍历字典中的 DataFrame
    for stock_code, df in result_local.items():
        # 确保 df 是一个 DataFrame
        if isinstance(df, pd.DataFrame):
            # 将时间戳转换为日期时间格式，只保留年-月-日
            df['time'] = pd.to_datetime(df['time'], unit='ms').dt.date
            # 将 'time' 列设置为索引，保留为日期格式
            df.set_index('time', inplace=True)
            # 指定列名
            df.columns = columns
            # 添加一列 'stock_code' 用于标识不同的股票
            df['stock_code'] = stock_code
            # 将 DataFrame 添加到列表中
            df_list.append(df[['close']])  # 只保留 'close' 列
        else:
            print(f"数据格式错误: {stock_code} 不包含 DataFrame")

    # 使用 pd.concat() 将所有 DataFrame 合并为一个大的 DataFrame
    combined_df = pd.concat(df_list, axis=1)

    # 确保返回的 DataFrame 索引是日期格式
    combined_df.index = pd.to_datetime(combined_df.index)

    # 打印最终的 DataFrame
    print(combined_df)

    return combined_df


def bt_strategy(data):

    # 计算策略信号
    # data = moving_average_strategy(data)

    # 定义策略
    dual_ma_strategy = bt.Strategy('Dual MA Strategy', [bt.algos.RunOnce(),
                                                        bt.algos.SelectAll(),
                                                        bt.algos.WeighEqually(),
                                                        bt.algos.Rebalance()])
    return dual_ma_strategy


# 运行回测
def run_backtest():
    # 生成数据
    data = get_local_data(field_list=[], stock_list=["300391.SZ"], period='1d', start_time='', end_time='', count=-1,
                          dividend_type='none', fill_data=True, data_dir="")

    # 创建策略
    strategy = bt_strategy(data)

    # 创建回测
    portfolio = bt.Backtest(strategy, data)
    result = bt.run(portfolio)

    return result


# 执行回测并显示结果
if __name__ == "__main__":
    result = run_backtest()
    result.plot()
    b = xtdata.get_sector_list()
    print(b)
    xtdata.download_sector_data()
    a = result.stats
    print(a)
    plt.show()
