import json

from fastapi import APIRouter

from src.backtest.service import start_backtest_service, stock_chart_service
from src.pydantic.backtest_request import BackRequest

router = APIRouter()  # 创建一个 FastAPI 路由器实例


@router.get("/start_backtest")
async def start_backtest(request: BackRequest):
    result = await start_backtest_service(field_list=['close', 'time'],
                                          stock_list=request.stock_list,
                                          period=request.period,
                                          start_time=request.start_time,
                                          end_time=request.end_time,
                                          count=request.count,
                                          dividend_type=request.dividend_type,
                                          fill_data=request.fill_data,
                                          ma_type=request.ma_type,
                                          short_window=request.short_window,
                                          long_window=request.long_window
                                          )
    return result


@router.get('/stock_chart')
async def stock_chart(request: BackRequest):
    result = await stock_chart_service(stock_code=request.stock_code,
                                       benchmark_code=request.benchmark_code)
    return result
