from tortoise import Model, fields
from src.models import with_table_name
from src.models.strategy import Strategy


class Backtest(Model):
    id = fields.IntField(pk=True)
    strategy: fields.ForeignKeyRelation[Strategy] = fields.ForeignKeyField(
        model_name="models.Strategy",
        related_name="integration_strategy",
        # db_constraint=False,
        on_delete=fields.CASCADE,
        index=True,
    )
    key = fields.CharField(max_length=20, unique=True, index=True, description="回测key")
    user_id = fields.IntField(null=True, description="回测用户")
    backtest_at = fields.DatetimeField(auto_now_add=True, description="回测时间")
    backtest_code = fields.TextField(description="回测代码")
    is_running = fields.BooleanField(default=True, description="回测状态")
    updated_at = fields.DatetimeField(auto_now=True, description="修改时间")
    deleted_at = fields.DatetimeField(null=True, description="删除时间")
    is_active = fields.BooleanField(default=True, description="是否可用")

    class Meta:
        table = with_table_name("Backtest")
