from pydantic import BaseModel, Field
from typing import Dict


class BenchmarkCodes(BaseModel):
    """
    模型类用于表示基准名称和对应代码的映射。
    """
    codes: Dict[str, str] = Field(
        default_factory=lambda: {
            "沪深300": "000300",  # 使用字符串来表示代码
            "中证500": "000905"
        },
        title="Benchmark Codes",
        description="A mapping of benchmark names to their respective codes."
    )

    # 添加一个属性或方法来根据基准名称返回代码
    async def get_code(self, benchmark_name: str) -> str:
        if benchmark_name in self.codes:
            return self.codes[benchmark_name]
        else:
            raise ValueError(f"Unknown benchmark name: {benchmark_name}")
