from tortoise.models import Model
from tortoise import fields, models
from tortoise.contrib.pydantic import pydantic_model_creator

from src.models import with_table_name, AccountType


class Order(Model):
    id = fields.IntField(pk=True, description="订单ID")
    stock_code = fields.CharField(max_length=30, description="股票代码")
    stock_name = fields.CharField(max_length=30, description="股票名称")
    limit_price = fields.FloatField(description="限价")
    order_quantity = fields.IntField(description="委托数量")
    order_amount = fields.FloatField(description="委托金额")
    order_type = fields.CharField(max_length=20, description="订单类型")  # 例如：买入、卖出
    position = fields.CharField(max_length=30, description="仓位")
    user_id = fields.IntField(null=False, description="用户Id")
    entrust_date = fields.DatetimeField(null=True, description="委托日期")
    entrust_time = fields.TimeField(null=True)

    class Meta:
        table = with_table_name("orders")


OrderResponse = pydantic_model_creator(
    Order
)


class Entrust(Model):
    id = fields.IntField(pk=True, description="主键id")
    fund_account = fields.IntField(null=True, description="资金账户")
    securities_alias = fields.CharField(max_length=30, null=True, description="账户别名")
    account_type = fields.IntEnumField(AccountType, null=True, description="账户类型")
    stock_code = fields.CharField(max_length=30, description="证券代码")
    stock_name = fields.CharField(max_length=30, null=False, description="证券名称")
    limit_price = fields.FloatField(description="委托价")
    entrust_number = fields.IntField(description="委托数量")
    deal_price = fields.FloatField(null=True, max_digits=10, description="成交价格")
    deal_number = fields.IntField(null=True, description="成家数量")
    order_type = fields.CharField(max_length=30, description="操作")  # 买入卖出
    entrust_date = fields.DateField(null=True, description="委托日期")
    entrust_money = fields.FloatField(description="委托金额")
    # Python
    is_repair = fields.BooleanField(default=False, index=True, description="是否补单")

    entrust_time = fields.TimeField(null=True)  # 委托时间

    class Meta:
        table = with_table_name("Entrust")


EntrustResponse = pydantic_model_creator(
    Entrust
)


class Backtesting(Model):
    id = fields.IntField(pk=True, description="主键id")
    key = fields.CharField(max_length=30, description="回测key")

    class Meta:
        table = with_table_name("backtest")


BacktestingResponse = pydantic_model_creator(
    Backtesting
)
