from tortoise import Model, fields
from tortoise.contrib.pydantic import pydantic_model_creator

from src.models import with_table_name


class TestTable(Model):
    """
       用户
    """
    id = fields.IntField(pk=True, description="主键")
    nickname = fields.CharField(max_length=30, null=True, description="用户昵称")
    avatar_url = fields.CharField(max_length=255, null=True, description="头像")
    member_type = fields.IntField(null=True, description="会员类型")
    beta_account_type = fields.CharField(null=True, max_length=30, description="内测账号类型")
    pre_cost_time = fields.IntField(null=True, description="预支付时间（单位年）")

    qr_code = fields.CharField(max_length=255, null=True, description="专属客服二维码")
    dedicated_id = fields.IntField(null=True, description="专属客服id")

    invited_user_id = fields.IntField(null=True, description="邀请人id")
    created_user_id = fields.IntField(null=True, description="创建人id")
    is_deleted = fields.BooleanField(default=False, index=True, description="是否删除")
    login_at = fields.DatetimeField(null=True, description="最后一次登录时间")
    created_at = fields.DatetimeField(auto_now_add=True, description="创建时间")
    updated_at = fields.DatetimeField(auto_now=True, description="修改时间")
    deleted_at = fields.DatetimeField(null=True, description="删除时间")

    class Meta:
        table = with_table_name("users")


UserResponse = pydantic_model_creator(
    TestTable
)
