from tortoise import Model, fields
from src.models import with_table_name
from src.models.strategy import Strategy


class Transaction(Model):
    id = fields.IntField(pk=True, description='主键')
    key = fields.CharField(max_length=20, description='key,数据标识')
    cash = fields.FloatField(description='资金', null=True)
    transaction_name = fields.CharField(max_length=255, description='交易名称')
    transaction_type = fields.CharField(max_length=255, null=True, description='交易类型')
    user_id = fields.IntField(null=True, description='用户id')
    is_running = fields.BooleanField(max_length=255, default=True, description='运行状态')
    is_deleted = fields.BooleanField(max_length=255, default=False, description='是否删除')
    process_id = fields.IntField(null=True, description='进程号')
    bar = fields.CharField(max_length=10, description='频率K线', null=True)
    created_at = fields.DatetimeField(auto_now_add=True, description="创建时间")
    updated_at = fields.DatetimeField(auto_now=True, description="修改时间")
    stopped_at = fields.DatetimeField(null=True, description="停止时间")
    deleted_at = fields.DatetimeField(null=True, description="删除时间")
    strategy: fields.ForeignKeyRelation[Strategy] = fields.ForeignKeyField(
        model_name="models.Strategy",
        related_name="transaction_strategy",
        # db_constraint=False,
        on_delete=fields.CASCADE,
        index=True,
    )

    class Meta:
        table = with_table_name("Transaction")
