from tortoise import Model, fields
from src.models import with_table_name

class WanceDataStorageBacktest(Model):
    avg_down_month = fields.FloatField(null=True, default=0, description='回测期间每个月下跌时的平均损失', )
    avg_drawdown = fields.FloatField(null=True, default=0, description='平均回撤，表示每次回撤的平均幅度', )
    avg_drawdown_days = fields.FloatField(null=True, default=0, description='平均回撤持续的天数', )
    avg_up_month = fields.FloatField(null=True, default=0, description='回测期间每个月上涨时的平均收益', )
    backtest_end_time = fields.IntField(description='回测结束时间', )
    backtest_name = fields.CharField(max_length=100, null=True, )
    best_day = fields.FloatField(null=True, default=0, description='回测期间单日的最大回报', )
    best_month = fields.FloatField(null=True, default=0, description='回测期间的最佳月份回报', )
    best_year = fields.FloatField(null=True, default=0, description='回测期间的最佳年度回报（若为空，表示回测不足一年）', )
    cagr = fields.FloatField(null=True, default=0, description='年化复合增长率，表示投资在整个回测期间的年均增长率', )
    calmar = fields.FloatField(null=True, default=0, description='Calmar 比率，表示年化收益率与最大回撤的比率，用于衡量风险调整后的收益。Calmar 比率越高，意味着风险调整后的表现越好', )
    daily_kurt = fields.FloatField(null=True, default=0, description='每日回报的峰度，表示回报分布的尖锐程度', )
    daily_mean = fields.FloatField(null=True, default=0, description='每日的平均回报率', )
    daily_price = fields.JSONField(null=True, description='每日的价格', )
    daily_sharpe = fields.FloatField(null=True, default=0, description='日频率的夏普比率，表示每单位风险所获得的超额收益', )
    daily_skew = fields.FloatField(null=True, default=0, description='每日回报的偏度，表示回报分布的对称性', )
    daily_sortino = fields.FloatField(null=True, default=0, description='日频率的 Sortino 比率，衡量投资组合的下行风险，考虑的是负波动率', )
    daily_vol = fields.FloatField(null=True, default=0, description='每日回报率的标准差（波动率），表示收益的波动性', )
    data_end_time = fields.CharField(max_length=10, null=True, description='回测数据结束时间', )
    data_start_time = fields.CharField(max_length=10, null=True, description='回测数据开始时间', )
    five_year = fields.FloatField(null=True, default=0, description='过去五年的回报', )
    id = fields.IntField(pk=True, )
    incep = fields.FloatField(null=True, default=0, description='自策略开始运行以来的年化回报率（如果策略没有完整的一年，则等于 cagr）', )
    indicator_information = fields.JSONField(null=True, description='指标信息', )
    indicator_type = fields.CharField(max_length=20, null=True, description='指标类型', )
    max_drawdown = fields.FloatField(null=True, default=0, description='最大回撤，表示投资组合在回测期间从最高点到最低点的最大亏损百分比', )
    monthly_kurt = fields.FloatField(null=True, default=0, description='月度回报的峰度', )
    monthly_mean = fields.FloatField(null=True, default=0, description='月度平均回报率', )
    monthly_sharpe = fields.FloatField(null=True, default=0, description='月频率的夏普比率', )
    monthly_skew = fields.FloatField(null=True, default=0, description='月度回报的偏度', )
    monthly_sortino = fields.FloatField(null=True, default=0, description='月频率的 Sortino 比率', )
    monthly_vol = fields.FloatField(null=True, default=0, description='月度回报率的标准差（波动率）', )
    mtd = fields.FloatField(null=True, default=0, description='月内截至目前的回报', )
    one_year = fields.FloatField(null=True, default=0, description='的回报', )
    position = fields.JSONField(null=True, description='持仓记录', )
    price = fields.JSONField(null=True, description='每日的余额', )
    returns = fields.JSONField(null=True, description='每日的回报率', )
    rf = fields.FloatField(null=True, default=0, description='无风险收益率，通常用来计算夏普比率等指标，通常为0表示忽略无风险收益', )
    six_month = fields.FloatField(null=True, default=0, description='过去六个月的回报（如果为空，表示无相关数据', )
    stock_close_price = fields.JSONField(null=True, description='股票收盘价', )
    stock_code = fields.CharField(max_length=20, null=True, )
    strategy_name = fields.CharField(max_length=50, null=True, description='回测的策略名称', )
    ten_year = fields.IntField(description='过去十年的回报', )
    three_month = fields.FloatField(null=True, default=0, description='过去三个月的回报', )
    three_year = fields.FloatField(null=True, default=0, description='过去三年的回报', )
    total_return = fields.FloatField(null=True, default=0, description='总回报率', )
    twelve_month_win_perc = fields.FloatField(null=True, default=0, description='过去12个月的胜率，表示在过去12个月中有多少月的回报为正', )
    win_year_perc = fields.FloatField(null=True, default=0, description='策略年度胜率，表示回测期间策略表现优于无风险收益率的年份百分比', )
    worst_day = fields.FloatField(null=True, default=0, description='回测期间单日的最差回报', )
    worst_month = fields.FloatField(null=True, default=0, description='回测期间的最差月份回报', )
    worst_year = fields.FloatField(null=True, default=0, description='回测期间的最差年度回报（若为空，表示回测不足一年）', )
    yearly_kurt = fields.FloatField(null=True, default=0, description='年度的峰度', )
    yearly_mean = fields.FloatField(null=True, default=0, description='年度的平均回报', )
    yearly_sharpe = fields.FloatField(null=True, default=0, description='年度的夏普比率', )
    yearly_skew = fields.FloatField(null=True, default=0, description='年度的偏度', )
    yearly_sortino = fields.FloatField(null=True, default=0, description='年度的Sortino 比率', )
    yearly_vol = fields.FloatField(null=True, default=0, description='年度的波动率', )
    ytd = fields.FloatField(null=True, default=0, description='年初至今的回报', )



    class Meta:
        table = with_table_name("wance_data_storage_backtest")