from typing import List, Optional, Any, Dict

from pydantic import BaseModel, Field


# 定义查询条件模型，覆盖所有字段
class StockQuery(BaseModel):
    financial_asset_value: Optional[float] = None
    financial_cash_flow: Optional[float] = None
    financial_dividend: Optional[float] = None
    financial_ex_gratia: Optional[float] = None
    financial_reserve_per: Optional[float] = None
    financial_undistributed_profit: Optional[float] = None
    growth_attributable_rate: Optional[float] = None
    growth_growth_rate: Optional[float] = None
    growth_Income_rate: Optional[float] = None
    growth_nonnet_profit: Optional[float] = None
    id: Optional[int] = None
    market_indicator: Optional[float] = None
    market_sector: Optional[str] = None
    profit_asset_value: Optional[float] = None
    profit_business_increase: Optional[float] = None
    profit_dividend_rate: Optional[float] = None
    profit_gross_rate: Optional[float] = None
    profit_sale_ratio: Optional[float] = None
    stock_code: Optional[str] = None
    stock_name: Optional[str] = None
    stock_sector: Optional[List[str]] = None
    stock_type: Optional[List[str]] = None
    time_start: Optional[str] = None
    time_end: Optional[str] = None
    time_expire: Optional[str] = None
    valuation_market_percentile: Optional[float] = None
    valuation_market_TTM: Optional[float] = None
    valuation_PB_percentile: Optional[float] = None
    valuation_PB_TTM: Optional[float] = None
    valuation_PEG_percentile: Optional[float] = None
    valuation_PEGTTM_ratio: Optional[float] = None
    valuation_PTS_percentile: Optional[float] = None
    valuation_PTS_TTM: Optional[float] = None
    gt: Optional[Dict[str, float]] = None  # 大于
    lt: Optional[Dict[str, float]] = None  # 小于
    gte: Optional[Dict[str, float]] = None  # 大于等于
    lte: Optional[Dict[str, float]] = None  # 小于等于
    between: Optional[Dict[str, Dict[str, float]]] = None  # 在某两个值之间

"""
# 这里是因子pydantic的定义

class FactorRequest(BaseModel):
    financial_asset_value: Optional[Dict[str, Any]] = Field(None, description='每股净资产')
    financial_cash_flow: Optional[Dict[str, Any]] = Field(None, description='每股现金流')
    financial_dividend: Optional[Dict[str, Any]] = Field(None, description='分红率')
    financial_ex_gratia: Optional[Dict[str, Any]] = Field(None, description='扣非后每股收益')
    financial_reserve_per: Optional[Dict[str, Any]] = Field(None, description='每股资本公积金')
    financial_undistributed_profit: Optional[Dict[str, Any]] = Field(None, description='每股未分配利润')
    growth_attributable_rate: Optional[Dict[str, Any]] = Field(None, description='归母净利润同比增长率')
    growth_growth_rate: Optional[Dict[str, Any]] = Field(None, description='营业利润同比增长率')
    growth_Income_rate: Optional[Dict[str, Any]] = Field(None, description='营业总收入同比增长率')
    growth_nonnet_profit: Optional[Dict[str, Any]] = Field(None, description='扣非净利润增长率')
    market_indicator: Optional[Dict[str, Any]] = Field(None, description='行情指标')
    market_sector: Optional[str] = Field(None, description='所属市场')
    profit_asset_value: Optional[Dict[str, Any]] = Field(None, description='净资产收益率')
    profit_business_increase: Optional[Dict[str, Any]] = Field(None, description='营业收入增长率')
    profit_dividend_rate: Optional[Dict[str, Any]] = Field(None, description='股息率')
    profit_gross_rate: Optional[Dict[str, Any]] = Field(None, description='销售毛利率')
    profit_sale_ratio: Optional[Dict[str, Any]] = Field(None, description='盈利销售净利率')
    stock_code: Optional[str] = Field(None, description='股票代码')
    stock_name: Optional[str] = Field(None, description='股票名称')
    stock_sector: Optional[List[str]] = Field(None, description='股票板块')
    stock_type: Optional[dict] = Field(None, description='股票类型')
    time_end: Optional[str] = Field(None, description='上一次回测结束时间')
    time_expire: Optional[str] = Field(None, description='退市时间')
    time_start: Optional[Dict[str, Any]] = Field(None, description='上市时间')
    valuation_market_percentile: Optional[Dict[str, Any]] = Field(None, description='市现率百分比')
    valuation_market_TTM: Optional[Dict[str, Any]] = Field(None, description='市现率TTM')
    valuation_PB_percentile: Optional[Dict[str, Any]] = Field(None, description='市净率百分位')
    valuation_PB_TTM: Optional[Dict[str, Any]] = Field(None, description='市净率TTM')
    valuation_PEG_percentile: Optional[Dict[str, Any]] = Field(None, description='市盈率百分位')
    valuation_PEGTTM_ratio: Optional[Dict[str, Any]] = Field(None, description='市盈率TTM')
    valuation_PTS_percentile: Optional[Dict[str, Any]] = Field(None, description='市销率百分位')
    valuation_PTS_TTM: Optional[Dict[str, Any]] = Field(None, description='市销率TTM')
"""

"""
使用示例：
    factor_request = FactorRequest(
    {
      "financial_asset_value": 10.7169,
      "financial_cash_flow": -0.42982,
      "gt": {
        "profit_gross_rate": 4.0,
        "valuation_PB_TTM": 0.8
      },
      "lt": {
        "market_indicator": -0.6
      },
      "gte": {
        "valuation_market_percentile":5.38793
      },
      "lte": {
        "valuation_PEGTTM_ratio": 15.2773
      },
      "between": {
        "financial_dividend": {
          "min": 1.0,
          "max": 2.0
        },
        "growth_Income_rate": {
          "min": -0.6,
          "max": 1.0
        }
      },
      "stock_code": "600051.SH",
      "stock_name": "宁波联合",
      "stock_sector": ["Shanghai A-shares", "Shenzhen A-shares"],
      "stock_type": ["stock"],
      "time_start": "0",
      "time_end": "20240911",
      "valuation_PEG_percentile": 15.2222,
      "valuation_PTS_TTM": 2.3077
    }
    )
    
    result = await WanceDataStock.dynamic_query(**factor_request.dict(exclude_none=True))
    print(result)
    
    
比较大小字段说明：
    'gt' 对应 __gt（大于）
    'lt' 对应 __lt（小于）
    'gte' 对应 __gte（大于等于）
    'lte' 对应 __lte（小于等于）
    'between' 对应在某个值之间的条件，使用 __gt 和 __lt 组合实现
    
时间字段说明：
    time_start={'recent_years': 2} 近2年
    time_start={'recent_months': 2} 近2月

"""
