from typing import List, Optional

from pydantic import BaseModel, Field


class DataRequest(BaseModel):
    field_list: List[str] = Field(default_factory=list, description="字段列表，用于指定获取哪些数据字段")
    stock_list: List[str] = Field(default_factory=list, description="股票列表，用于指定获取哪些股票的数据")
    stock_code: str = Field(default="000300.SH", description="股票代码，用于指定获取哪些股票的数据")
    period: str = Field(default='1d', description="数据周期，如 '1d' 表示日线数据")
    start_time: Optional[str] = Field(default='', description="开始时间，格式为 'YYYY-MM-DD'，默认为空字符串")
    end_time: Optional[str] = Field(default='', description="结束时间，格式为 'YYYY-MM-DD'，默认为空字符串")
    count: int = Field(default=-1, description="数据条数，默认为 -1 表示获取所有数据")
    dividend_type: str = Field(default='none', description="分红类型，默认值为 'none'")
    fill_data: bool = Field(default=True, description="是否填充数据，默认为 True")
    incrementally: bool = Field(default=True, description="是否增量下载")
    callback: bool = Field(default=True, description="是否开启回调函数")
    data_dir: str = Field(default="D:\\e海方舟-量化交易版\\userdata_mini\\datadir", description="数据存储路径")
    sector_name:str = Field(default="沪深指数", description="板块名称")
    iscomplete: bool = Field(default=False, description="是否获取全部字段")

