from typing import Any

from pydantic import  RedisDsn, model_validator
from pydantic_settings import BaseSettings

from src.constants import Environment


class Config(BaseSettings):
    DATABASE_PREFIX: str = ""
    DATABASE_URL: str
    DATABASE_CREATE_URL: str
    REDIS_URL: RedisDsn

    SITE_DOMAIN: str = "myapp.com"

    ENVIRONMENT: Environment = Environment.PRODUCTION

    SENTRY_DSN: str | None = None

    CORS_ORIGINS: list[str]
    CORS_ORIGINS_REGEX: str | None = None
    CORS_HEADERS: list[str]

    APP_VERSION: str = "1"
    APP_ROUTER_PREFIX: str = "/api/v1"

    SHOULD_SEND_SMS: bool = False

    @model_validator(mode="after")
    def validate_sentry_non_local(self) -> "Config":
        if self.ENVIRONMENT.is_deployed and not self.SENTRY_DSN:
            raise ValueError("Sentry is not set")

        return self


settings = Config()

# fastapi/applications.py
app_configs: dict[str, Any] = {
    "title": "Wance QMT API",
    "root_path": settings.APP_ROUTER_PREFIX,
    "docs_url": "/api/docs",
}

# app_configs['debug'] = True
# if settings.ENVIRONMENT.is_deployed:
#     app_configs["root_path"] = f"/v{settings.APP_VERSION}"
#
# if not settings.ENVIRONMENT.is_debug:
#     app_configs["openapi_url"] = None  # hide docs
