import difflib
import re

import pandas as pd


def arrays_to_dict(Chinese: list, English: list) -> dict:
    # 使用 zip 将两个数组配对，然后转换为字典
    return dict(zip(Chinese, English))


# 中文数组
Chinese = [
    "上证A股", "深证A股", "沪深300", "中证500", "中证1000", "国证2000", "农林牧渔基础", "化工钢铁", "有色金属",
    "电子", "汽车", "家用电器", "食品饮料", "纺织服饰", "轻工制造", "医药生物", "公用事业", "交通运输",
    "房地产", "商贸零售", "社会服务", "银行", "非银金融", "综合", "建筑材料", "建筑装饰", "电力设备",
    "机械设备", "国防军工", "计算机", "传媒", "通信", "煤炭", "石油石化", "环保", "美容护理", "中字头股票",
    "中特估100", "人形机器人", "低空经济", "数字货币", "工业互联网", "Web3.0", "网络直播", "跨境电商",
    "消费电子概念", "网络游戏", "国产软件", "抖音概念", "手机游戏", "元宇宙", "区块链", "虚拟现实", "量子科技",
    "智能穿戴", "机器视觉", "ChatGPT概念", "脑机接口", "人工智能", "机器人概念", "数字孪生", "算力租赁", "碳中和",
    "风电", "光热发电", "光伏概念", "中俄贸易概念", "露营经济", "柔性屏", "宠物经济", "免税店", "预制菜",
    "在线旅游", "减肥药", "体育产业", "无人机", "华为海思概念股", "先进封装（Chiplet）", "第三代半导体", "中芯国际概念",
    "光刻机", "氟化工概念", "光刻胶", "汽车芯片", "传感器", "英伟达概念", "边缘计算", "存储芯片", "6G概念",
    "石墨烯", "芯片概念", "特斯拉", "充电桩", "抽水蓄能", "固态电池", "一体化压铸", "动力电池回收", "新能源汽车",
    "钠离子电池", "储能", "钙钛矿电池", "汽车电子", "稀土永磁", "华为汽车", "毫米波雷达", "锂电池", "阿尔茨海默概念",
    "创新药", "仿制药一致性评价", "重组蛋白", "毛发医疗", "生物医药", "医美概念辅助生殖", "生物疫苗", "细胞免疫治疗",
    "基因测序", "集成电路概念", "黄金概念", "新疆振兴", "一带一路", "养老概念", "新材料概念", "职业教育", "工业4.0",
    "碳纤维", "军工", "航运概念", "独角兽概念", "国家大基金持股", "海南自贸区", "专精特新", "智能制造", "超超临界发电"
]

# 英文数组（仅为示例，可以根据具体需求替换成正确的英文）
English = [
    "Shanghai A-shares", "Shenzhen A-shares", "CSI 300", "CSI 500", "CSI 1000", "CSI 2000", "Agriculture and Forestry",
    "Chemical and Steel", "Non-ferrous Metals", "Electronics", "Automobile", "Household Appliances",
    "Food and Beverage",
    "Textiles and Apparel", "Light Industry Manufacturing", "Pharmaceuticals", "Public Utilities", "Transportation",
    "Real Estate", "Retail", "Social Services", "Banking", "Non-bank Finance", "Comprehensive", "Building Materials",
    "Building Decoration", "Electric Power Equipment", "Machinery", "Defense", "Computer", "Media", "Telecom", "Coal",
    "Petroleum", "Environmental Protection", "Beauty Care", "State-owned Enterprises", "Special Valuation 100",
    "Humanoid Robot",
    "Low-altitude Economy", "Digital Currency", "Industrial Internet", "Web3.0", "Live Streaming",
    "Cross-border E-commerce",
    "Consumer Electronics", "Online Games", "Domestic Software", "Douyin Concept", "Mobile Games", "Metaverse",
    "Blockchain",
    "Virtual Reality", "Quantum Technology", "Wearable Devices", "Machine Vision", "ChatGPT Concept",
    "Brain-computer Interface",
    "Artificial Intelligence", "Robotics", "Digital Twin", "Computing Power Leasing", "Carbon Neutrality", "Wind Power",
    "Solar Thermal", "Photovoltaic", "China-Russia Trade", "Camping Economy", "Flexible Screen", "Pet Economy",
    "Duty-free",
    "Prepared Foods", "Online Travel", "Weight Loss Drugs", "Sports Industry", "Drone", "Huawei HiSilicon", "Chiplet",
    "Third-generation Semiconductors", "SMIC Concept", "Lithography Machine", "Fluorine Chemicals", "Photoresist",
    "Automotive Chips", "Sensors", "NVIDIA Concept", "Edge Computing", "Memory Chips", "6G Concept", "Graphene",
    "Chip Concept",
    "Tesla", "Charging Pile", "Pumped Storage", "Solid-state Battery", "Integrated Die-casting", "Battery Recycling",
    "New Energy Vehicles", "Sodium-ion Battery", "Energy Storage", "Perovskite Battery", "Automotive Electronics",
    "Rare Earth",
    "Huawei Vehicles", "Millimeter Wave Radar", "Lithium Battery", "Alzheimer's Concept", "Innovative Drugs",
    "Generic Drugs",
    "Recombinant Protein", "Hair Medical", "Biomedical", "Aesthetic Medicine", "Reproductive Assistance", "Biovaccine",
    "Cell Immunotherapy", "Gene Sequencing", "IC Concept", "Gold Concept", "Xinjiang Development", "Belt and Road",
    "Elderly Care Concept", "New Materials", "Vocational Education", "Industry 4.0", "Carbon Fiber", "Military",
    "Shipping",
    "Unicorn Concept", "National Fund Holdings", "Hainan Free Trade Zone", "Specialized and New", "Smart Manufacturing",
    "Ultra-supercritical Power"
]

# 调用方法
result_dict = arrays_to_dict(Chinese, English)


translation_dict = {
    "上证A股": "Shanghai A-shares",
    "深证A股": "Shenzhen A-shares",
    "沪深300": "CSI 300",
    "中证500": "CSI 500",
    "中证1000": "CSI 1000",
    "国证2000": "CSI 2000",
    "农林牧渔基础": "Agriculture and Forestry",
    "化工钢铁": "Chemical and Steel",
    "有色金属": "Non-ferrous Metals",
    "电子": "Electronics",
    "汽车": "Automobile",
    "家用电器": "Household Appliances",
    "食品饮料": "Food and Beverage",
    "纺织服饰": "Textiles and Apparel",
    "轻工制造": "Light Industry Manufacturing",
    "医药生物": "Pharmaceuticals",
    "公用事业": "Public Utilities",
    "交通运输": "Transportation",
    "房地产": "Real Estate",
    "商贸零售": "Retail",
    "社会服务": "Social Services",
    "银行": "Banking",
    "非银金融": "Non-bank Finance",
    "综合": "Comprehensive",
    "建筑材料": "Building Materials",
    "建筑装饰": "Building Decoration",
    "电力设备": "Electric Power Equipment",
    "机械设备": "Machinery",
    "国防军工": "Defense",
    "计算机": "Computer",
    "传媒": "Media",
    "通信": "Telecom",
    "煤炭": "Coal",
    "石油石化": "Petroleum",
    "环保": "Environmental Protection",
    "美容护理": "Beauty Care",
    "中字头股票": "State-owned Enterprises",
    "中特估100": "Special Valuation 100",
    "人形机器人": "Humanoid Robot",
    "低空经济": "Low-altitude Economy",
    "数字货币": "Digital Currency",
    "工业互联网": "Industrial Internet",
    "Web3.0": "Web3.0",
    "网络直播": "Live Streaming",
    "跨境电商": "Cross-border E-commerce",
    "消费电子概念": "Consumer Electronics",
    "网络游戏": "Online Games",
    "国产软件": "Domestic Software",
    "抖音概念": "Douyin Concept",
    "手机游戏": "Mobile Games",
    "元宇宙": "Metaverse",
    "区块链": "Blockchain",
    "虚拟现实": "Virtual Reality",
    "量子科技": "Quantum Technology",
    "智能穿戴": "Wearable Devices",
    "机器视觉": "Machine Vision",
    "ChatGPT概念": "ChatGPT Concept",
    "脑机接口": "Brain-computer Interface",
    "人工智能": "Artificial Intelligence",
    "机器人概念": "Robotics",
    "数字孪生": "Digital Twin",
    "算力租赁": "Computing Power Leasing",
    "碳中和": "Carbon Neutrality",
    "风电": "Wind Power",
    "光热发电": "Solar Thermal",
    "光伏概念": "Photovoltaic",
    "中俄贸易概念": "China-Russia Trade",
    "露营经济": "Camping Economy",
    "柔性屏": "Flexible Screen",
    "宠物经济": "Pet Economy",
    "免税店": "Duty-free",
    "预制菜": "Prepared Foods",
    "在线旅游": "Online Travel",
    "减肥药": "Weight Loss Drugs",
    "体育产业": "Sports Industry",
    "无人机": "Drone",
    "华为海思概念股": "Huawei HiSilicon",
    "先进封装（Chiplet）": "Chiplet",
    "第三代半导体": "Third-generation Semiconductors",
    "中芯国际概念": "SMIC Concept",
    "光刻机": "Lithography Machine",
    "氟化工概念": "Fluorine Chemicals",
    "光刻胶": "Photoresist",
    "汽车芯片": "Automotive Chips",
    "传感器": "Sensors",
    "英伟达概念": "NVIDIA Concept",
    "边缘计算": "Edge Computing",
    "存储芯片": "Memory Chips",
    "6G概念": "6G Concept",
    "石墨烯": "Graphene",
    "芯片概念": "Chip Concept",
    "特斯拉": "Tesla",
    "充电桩": "Charging Pile",
    "抽水蓄能": "Pumped Storage",
    "固态电池": "Solid-state Battery",
    "一体化压铸": "Integrated Die-casting",
    "动力电池回收": "Battery Recycling",
    "新能源汽车": "New Energy Vehicles",
    "钠离子电池": "Sodium-ion Battery",
    "储能": "Energy Storage",
    "钙钛矿电池": "Perovskite Battery",
    "汽车电子": "Automotive Electronics",
    "稀土永磁": "Rare Earth",
    "华为汽车": "Huawei Vehicles",
    "毫米波雷达": "Millimeter Wave Radar",
    "锂电池": "Lithium Battery",
    "阿尔茨海默概念": "Alzheimer's Concept",
    "创新药": "Innovative Drugs",
    "仿制药一致性评价": "Generic Drugs",
    "重组蛋白": "Recombinant Protein",
    "毛发医疗": "Hair Medical",
    "生物医药": "Biomedical",
    "医美概念辅助生殖": "Aesthetic Medicine",
    "生物疫苗": "Biovaccine",
    "细胞免疫治疗": "Cell Immunotherapy",
    "基因测序": "Gene Sequencing",
    "集成电路概念": "IC Concept",
    "黄金概念": "Gold Concept",
    "新疆振兴": "Xinjiang Development",
    "一带一路": "Belt and Road",
    "养老概念": "Elderly Care Concept",
    "新材料概念": "New Materials",
    "职业教育": "Vocational Education",
    "工业4.0": "Industry 4.0",
    "碳纤维": "Carbon Fiber",
    "军工": "Military",
    "航运概念": "Shipping",
    "独角兽概念": "Unicorn Concept",
    "国家大基金持股": "National Fund Holdings",
    "海南自贸区": "Hainan Free Trade Zone",
    "专精特新": "Specialized and New",
    "智能制造": "Smart Manufacturing",
    "超超临界发电": "Ultra-supercritical Power"
}


def chinese_to_english(chinese_term):
    return translation_dict.get(chinese_term, "Translation not found")


def english_to_chinese(english_term):
    # Invert the dictionary for reverse lookup
    inverted_dict = {v: k for k, v in translation_dict.items()}
    return inverted_dict.get(english_term, "Translation not found")


def fuzzy_search(pattern, string_list):
    """
    使用正则表达式在字符串列表中进行模糊搜索。

    :param pattern: 要搜索的模式（字符串）
    :param string_list: 字符串列表
    :return: 匹配的字符串列表
    """
    regex = re.compile(pattern)
    return [s for s in string_list if regex.search(s)]


def get_best_match(sector, translation_dict):
    """
    模糊匹配获取最佳匹配的中文板块。
    @param sector: 需要匹配的中文板块名
    @param translation_dict: 中文板块到英文的映射字典
    @return: 最佳匹配的中文板块名（如果找到），否则返回None
    """
    matches = difflib.get_close_matches(sector, translation_dict.keys(), n=1, cutoff=0.6)
    return matches[0] if matches else None


def on_progress(data):
    print("这里是回执数据", data)


def safe_get_value(value):
    """检查值是否为 None、NaN 或 False，如果是，则返回 0，否则返回值本身"""
    if value is None or pd.isna(value) or value is False:
        return 0
    return value
