from tortoise.models import Model
from tortoise import fields
from tortoise.functions import Count

# 调用异步方法
import asyncio

from src.models.wance_data_stock import WanceDataStock
from src.tortoises_orm_config import init_tortoise


async def remove_duplicates():
    await init_tortoise()

    # 获取重复的股票代码和时间
    duplicates = await WanceDataStock.all().group_by('stock_code', 'time_end').annotate(count=Count('id')).filter(
        count__gt=1)

    if not duplicates:
        print("No duplicates found.")
        return

    print(f"Found {len(duplicates)} duplicates.")

    for record in duplicates:
        # 查询相同 stock_code 和 time_end 的所有记录，并按 id 逆序排序
        duplicate_records = await WanceDataStock.filter(stock_code=record.stock_code,
                                                        time_end=record.time_end).order_by('-id')

        # 输出当前处理的记录
        print(
            f"Processing {len(duplicate_records)} records for stock_code={record.stock_code} and time_end={record.time_end}.")

        if duplicate_records:
            # 删除最新的一条记录，保留其余的
            await WanceDataStock.filter(id=duplicate_records[0].id).delete()
            print(f"Deleted record with id={duplicate_records[0].id}")


asyncio.run(remove_duplicates())
